Crate hyraigne

Crate hyraigne 

Hyraigne provides web spiders (a.k.a. web crawlers) to scrape websites like webtoons.com or mangadex.org and helps you download chapters from there.

Structs

Chapter
A chapter.
Filter
Chapter filter.
Options
Web spider options.
Page
A page.
Series
A series.

Enums

Error
An error that may occur while scraping a website.

Traits

Site
A website scraper.

Functions

get_spider_for
Return a web spider adapted to the given URL.

Type Aliases

Result
A specialized Result type for scraping operations.